pub struct BlockTimestamp {
pub slot: Slot,
pub timestamp: UnixTimestamp,
}Fields
slot: Slottimestamp: UnixTimestampTrait Implementations
Sourceimpl AbiExample for BlockTimestamp
impl AbiExample for BlockTimestamp
Sourceimpl<'arbitrary> Arbitrary<'arbitrary> for BlockTimestamp
impl<'arbitrary> Arbitrary<'arbitrary> for BlockTimestamp
Sourcefn arbitrary(u: &mut Unstructured<'arbitrary>) -> Result<Self>
fn arbitrary(u: &mut Unstructured<'arbitrary>) -> Result<Self>
Generate an arbitrary value of
Self from the given unstructured data. Read moreSourcefn arbitrary_take_rest(u: Unstructured<'arbitrary>) -> Result<Self>
fn arbitrary_take_rest(u: Unstructured<'arbitrary>) -> Result<Self>
Generate an arbitrary value of
Self from the entirety of the given
unstructured data. Read moreSourcefn size_hint(depth: usize) -> (usize, Option<usize>)
fn size_hint(depth: usize) -> (usize, Option<usize>)
Get a size hint for how many bytes out of an
Unstructured this type
needs to construct itself. Read moreSourcefn try_size_hint(
depth: usize,
) -> Result<(usize, Option<usize>), MaxRecursionReached>
fn try_size_hint( depth: usize, ) -> Result<(usize, Option<usize>), MaxRecursionReached>
Get a size hint for how many bytes out of an
Unstructured this type
needs to construct itself. Read moreSourceimpl Clone for BlockTimestamp
impl Clone for BlockTimestamp
Sourcefn clone(&self) -> BlockTimestamp
fn clone(&self) -> BlockTimestamp
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BlockTimestamp
impl Debug for BlockTimestamp
Sourceimpl Default for BlockTimestamp
impl Default for BlockTimestamp
Sourcefn default() -> BlockTimestamp
fn default() -> BlockTimestamp
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for BlockTimestamp
impl<'de> Deserialize<'de> for BlockTimestamp
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Distribution<BlockTimestamp> for StandardUniform
impl Distribution<BlockTimestamp> for StandardUniform
impl Eq for BlockTimestamp
Sourceimpl PartialEq for BlockTimestamp
impl PartialEq for BlockTimestamp
Sourcefn eq(&self, other: &BlockTimestamp) -> bool
fn eq(&self, other: &BlockTimestamp) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl<'de, WincodeConfig: Config> SchemaRead<'de, WincodeConfig> for BlockTimestamp
impl<'de, WincodeConfig: Config> SchemaRead<'de, WincodeConfig> for BlockTimestamp
type Dst = BlockTimestamp
Sourcefn read(
reader: impl Reader<'de>,
dst: &mut MaybeUninit<Self::Dst>,
) -> ReadResult<()>
fn read( reader: impl Reader<'de>, dst: &mut MaybeUninit<Self::Dst>, ) -> ReadResult<()>
Sourceimpl<WincodeConfig: Config> SchemaWrite<WincodeConfig> for BlockTimestamp
impl<WincodeConfig: Config> SchemaWrite<WincodeConfig> for BlockTimestamp
Sourceimpl Serialize for BlockTimestamp
impl Serialize for BlockTimestamp
Sourceimpl StableAbi for BlockTimestamp
impl StableAbi for BlockTimestamp
impl StructuralPartialEq for BlockTimestamp