pub struct TowerSync {
pub lockouts: VecDeque<Lockout>,
pub root: Option<Slot>,
pub hash: Hash,
pub timestamp: Option<UnixTimestamp>,
pub block_id: Hash,
}Fields
lockouts: VecDeque<Lockout>The proposed tower
root: Option<Slot>The proposed root
hash: Hashsignature of the bank’s state at the last slot
timestamp: Option<UnixTimestamp>processing timestamp of last slot
block_id: Hashthe unique identifier for the chain up to and including this block. Does not require replaying in order to compute.
Implementations
Sourceimpl TowerSync
impl TowerSync
pub fn new( lockouts: VecDeque<Lockout>, root: Option<Slot>, hash: Hash, block_id: Hash, ) -> Self
Sourcepub fn new_from_slot(slot: Slot, hash: Hash) -> Self
pub fn new_from_slot(slot: Slot, hash: Hash) -> Self
Creates a tower with consecutive votes for slot - MAX_LOCKOUT_HISTORY + 1 to slot inclusive.
If slot >= MAX_LOCKOUT_HISTORY, sets the root to (slot - MAX_LOCKOUT_HISTORY)
Sets the hash to hash and leaves block_id unset.
Sourcepub fn new_from_slots(slots: Vec<Slot>, hash: Hash, root: Option<Slot>) -> Self
pub fn new_from_slots(slots: Vec<Slot>, hash: Hash, root: Option<Slot>) -> Self
Creates a tower with consecutive confirmation for slots
pub fn slots(&self) -> Vec<Slot> ⓘ
pub fn last_voted_slot(&self) -> Option<Slot>